pub fn names() -> Vec<String>Expand description
Returns the names of potential trunk branches, per GRIT_TRUNKS (if set)
or DEFAULT_TRUNKS.
pub fn names() -> Vec<String>Returns the names of potential trunk branches, per GRIT_TRUNKS (if set)
or DEFAULT_TRUNKS.